See An [Gurux](http://www.gurux.org/ "Gurux") for an overview.

Join the Gurux Community or follow [@Gurux](https://twitter.com/guruxorg "@Gurux") for project updates.

gurux.common.python package implements interfaces that are needed for Gurux Media components and Gurux Device Framework. 
Purpose of Gurux Device Framework is help you to read your devices, meters and sensors easier.

For more info check out [Gurux](http://www.gurux.org/ "Gurux").

We are updating documentation on Gurux web page. 

If you have problems you can ask your questions in Gurux [Forum](http://www.gurux.org/forum).

You can get source codes from http://www.github.com/gurux or intall package: 

```python
pip install gurux-common
```
